#!/usr/bin/env python

import os
import time
from dm.common.utility.loggingManager import LoggingManager
from dm.common.utility.timeUtility import TimeUtility
from dm.common.processing.plugins.fileProcessor import FileProcessor
from dm.common.mongodb.api.fileMongoDbApi import FileMongoDbApi

class MongoDbFileCatalogPlugin(FileProcessor):

    def __init__(self):
        FileProcessor.__init__(self)
        self.fileMongoDbApi = FileMongoDbApi()
        self.logger = LoggingManager.getInstance().getLogger(self.__class__.__name__)

    def processFile(self, fileInfo):
        experimentFilePath = fileInfo.get('experimentFilePath')
        experiment = fileInfo.get('experiment')
        experimentName = experiment.get('name')
        self.logger.debug('Processing file %s for experiment %s' % (fileInfo, experimentName))

        experimentStorageDirectory = experiment.get('storageDirectory')
        storageHost = experiment.get('storageHost')
        storageFilePath = os.path.join(experimentStorageDirectory, experimentFilePath)
        fileProcessingTime = time.time()
        fileProcessingTimeStamp = TimeUtility.formatLocalTimeStamp(fileProcessingTime)

        # Prepare catalogging entry
        fileInfo2 = {}
        for key in ['md5Sum', 'fileSize', 'fileCreationTime', 'fileCreationTimeStamp']:
            if fileInfo.has_key(key):
                fileInfo2[key] = fileInfo.get(key, '')
        fileInfo2['fileName'] = os.path.basename(experimentFilePath)
        fileInfo2['experimentStorageDirectory'] = experimentStorageDirectory
        fileInfo2['storageHost'] = storageHost
        fileInfo2['storageFilePath'] = storageFilePath
        fileInfo2['experimentFilePath'] = experimentFilePath
        fileInfo2['experimentName'] = experimentName
        fileInfo2['fileProcessingTime'] = fileProcessingTime
        fileInfo2['fileProcessingTimeStamp'] = fileProcessingTimeStamp
        fileInfo2.update(fileInfo.get('daqInfo', {}))
        self.fileMongoDbApi.updateOrAddExperimentFile(fileInfo2)


#######################################################################
# Testing.
if __name__ == '__main__':
    pass
